@@ -1,4 +1,9 @@
 
+###########################################################################
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
+###########################################################################
+
 package CGI::FormBuilder::Field;
 
 =head1 NAME
@@ -40,12 +45,14 @@ CGI::FormBuilder::Field - Base class for FormBuilder fields
 
 use Carp;   # confess used manually in this pkg
 use strict;
-
-our $VERSION = '3.0302';
-our $AUTOLOAD;
+use warnings;
+no  warnings 'uninitialized';
 
 use CGI::FormBuilder::Util;
 
+our $VERSION = '3.10';
+our $AUTOLOAD;
+
 # what to generate for tag
 our @TAGATTR = qw(name type multiple jsclick);
 
@@ -102,31 +109,31 @@ sub new {
     my $self = shift;
 
     my $form = shift;       # need for top-level attr
-    my %opt  = ref $_[0] eq 'HASH' ? %{$_[0]} : @_;
-    $opt{_form} = $form;    # parental ptr
-    puke "Missing name for field() in Field->new()" unless $opt{name};
+    my $opt  = arghash(@_);
+    $opt->{_form} = $form;    # parental ptr
+    puke "Missing name for field() in Field->new()"
+        unless $opt->{name};
 
     my $class = ref($self) || $self;
-    my $f = bless \%opt, $class;
+    my $f = bless $opt, $class;
 
-    #
-    # XXX This is ugly and I don't really like it.
-    # XXX ->type re-blesses the object into the appropriate
-    # XXX ::type.pm classes as a side-effect. As such, calling
-    # XXX in a void context will morph it into the proper object.
-    # XXX There should be a cleaner way of doing this.
-    #
-    #$f->type;      # does not work - must call w/i script()
+    # Note that at this point, the object is a generic field
+    # without a type. Not until it's called via $f->type does
+    # it get a type, which affects its HTML representation.
+    # Everything else is inherited from this module.
 
     return $f;
 }
 
 sub field {
     my $self = shift;
-    my %opt  = ref $_[0] eq 'HASH' ? %{$_[0]} : @_;
-    while (my($k,$v) = each %opt) {
-        next if $k eq 'name';   # segfault??
-        $self->{$k} = $v;
+
+    if (ref $_[0] || @_ > 1) {
+        my $opt = arghash(@_);
+        while (my($k,$v) = each %$opt) {
+            next if $k eq 'name';   # segfault??
+            $self->{$k} = $v;
+        }
     }
     return $self->value;    # needed for @v = $form->field('name')
 }
@@ -158,17 +165,18 @@ sub othertag {
     return '' unless $self->other;
 
     # add an additional tag for our _other field
-    my %oa = $self->other;  # other attr
+    my $oa = $self->other;  # other attr
 
     # default settings
-    $oa{type}  ||= 'text';
+    $oa->{type}  ||= 'text';
     my $v = $self->{_form}->cgi_param($self->othername);
-    if ($self->sticky and $v) {
-        $oa{value} = $v;
+    #$v = $self->tag_value unless defined $v;
+    if ($self->sticky and defined $v) {
+        $oa->{value} = $v;
     }
 
-    $oa{disabled} = 'disabled' if $self->javascript && ! $v;   # fanciness
-    return htmltag('input', %oa);
+    $oa->{disabled} = 'disabled' if $self->javascript && ! defined $v;   # fanciness
+    return htmltag('input', $oa);
 }
 
 sub growname {
@@ -180,10 +188,12 @@ sub cgi_value {
     my $self = shift;
     debug 2, "$self->{name}: called \$field->cgi_value";
     puke "Cannot set \$field->cgi_value manually" if @_;
-    if (my @v = $self->{_form}{params}->param($self->name)) {
-        if ($v[0] eq $self->othername) {
-            debug 1, "$self->{name}: redoing value from _other field";
-            @v = $self->{_form}{params}->param($self->othername);
+    if (my @v = $self->{_form}{params}->can('multi_param') ? $self->{_form}{params}->multi_param($self->name) : $self->{_form}{params}->param($self->name)) {
+        for my $v (@v) {
+            if ($self->other && $v eq $self->othername) {
+                debug 1, "$self->{name}: redoing value from _other field";
+                $v = $self->{_form}{params}->param($self->othername);
+            }
         }
         local $" = ',';
         debug 2, "$self->{name}: cgi value = (@v)";
@@ -202,9 +212,54 @@ sub def_value {
     my @v = autodata $self->{value};
     local $" = ',';
     debug 2, "$self->{name}: def value = (@v)";
+    $self->inflate_value(\@v);
     return wantarray ? @v : $v[0];
 }
 
+sub inflate_value {
+    my ($self, $v_aref) = @_;
+
+    debug 2, "$self->{name}: called \$field->inflate_value";
+
+    # trying to inflate?
+    return unless exists $self->{inflate};
+    debug 2, "$self->{name}: inflate routine exists";
+
+    # must return real values to the validate() routine:
+    return if grep { ((caller($_))[3] eq 'CGI::FormBuilder::Field::validate') } 
+                1..2;
+    debug 2, "$self->{name}: made sure inflate not called via validate";
+
+    # must be valid:
+    #return unless exists $self->{invalid} && ! $self->{invalid};
+    return if $self->invalid;
+    debug 2, "$self->{name}: valid field, inflate proceeding";
+
+    my $cache = $self->{inflated_values};
+
+    if ($cache && ref $cache eq 'ARRAY' && @{$cache}) {
+        # could have been cached by validate() check
+        @{ $v_aref } = @{ $self->{inflated_values} };
+        debug 2, "$self->{name}: using cached inflate "
+               . "value from validate()";
+    }
+    else {
+        debug 2, "$self->{name}: new inflate";
+
+        puke("Field $self->{name}: inflate must be a reference to a \\&sub")
+            if ref $self->{inflate} ne 'CODE';
+
+        eval { @{ $v_aref } = map $self->{inflate}->($_), @{ $v_aref } };
+
+        # no choice but to die hard if didn't validate() first
+        puke("Field $self->{name}: inflate failed: $@") if $@;
+
+        # cache the result:
+        @{ $self->{inflated_values} } = @{ $v_aref };
+    }
+    return;
+}
+
 # CGI.pm happiness
 *default  = \&value;
 *defaults = \&value;
@@ -222,6 +277,7 @@ sub value {
         if (my @v = $self->cgi_value) {
             local $" = ',';
             debug 1, "$self->{name}: returning value (@v)";
+            $self->inflate_value(\@v);
             return wantarray ? @v : $v[0];
         }
     }
@@ -255,6 +311,18 @@ sub tag_value {
     return $self->def_value;
 }
 
+# Handle "b:select" and "b:option"
+sub tag_name {
+    my $self = shift;
+    $self->{tag_name} = shift if @_;
+    return $self->{tag_name} if $self->{tag_name};
+    # Try to guess
+    my($tag) = ref($self) =~ /^CGI::FormBuilder::Field::(.+)/;
+    puke "Can't resolve tag for untyped field '$self->{name}'"
+        unless $tag;
+    return $tag;
+}
+
 sub type {
     local $^W = 0;    # -w sucks
     my $self = shift;
@@ -340,6 +408,7 @@ sub type {
 
     # Re-bless into the appropriate package
     my $pkg = __PACKAGE__ . '::' . $type;
+    $pkg =~ s/\-/_/g;  # handle HTML5 type names ala 'datetime-local'
     eval "require $pkg";
     puke "Can't load $pkg for field '$name' (type '$type'): $@" if $@;
     bless $self, $pkg;
@@ -570,6 +639,7 @@ sub jsfield {
     $jsfunc .= <<EOJS;
 $in    alertstr += '$alertstr';
 $in    invalid++;
+$in    invalid_fields.push('$jsfield');
 $in}$close_brace
 EOJS
 
@@ -588,13 +658,21 @@ sub validate () {
     # This function does all the validation on the Perl side.
     # It doesn't generate JavaScript; see render() for that...
 
-    my $self = shift;
-    my $form = $self->{_form};   # alias for examples (paint-by-numbers)
+    my $self  = shift;
+    my $form  = $self->{_form};   # alias for examples (paint-by-numbers)
     local $^W = 0;               # -w sucks
 
     my $pattern = shift || $self->{validate};
     my $field   = $self->name;
 
+    # inflation subref?
+    my $inflate = (exists $self->{inflate}) ? $self->{inflate} : undef;
+    puke("$field: inflate attribute must be subroutine reference")
+        if defined $inflate && ref $inflate ne 'CODE';
+    puke("$field: inflate requires a validation pattern")
+        if defined $inflate && !defined $pattern;
+    $self->{inflated_values} = [ ] if $inflate;
+
     debug 1, "$self->{name}: called \$field->validate(@_) for field '$field'";
 
     # Check our hash to see if it's a special pattern
@@ -642,8 +720,9 @@ sub validate () {
             }
         } elsif (ref $pattern eq 'CODE') {
             # eval that mofo, which gives them $form
-            debug 2, "$field: does $pattern($value) ret true ?";
-            unless (&{$pattern}($value)) {
+            my $extra = $form->{c} || $form;
+            debug 2, "$field: does $pattern($value, $extra) ret true ?";
+            unless (&{$pattern}($value, $extra)) {
                 $thisfail = ++$bad;
             }
         } elsif ($pattern eq 'VALUE') {
@@ -652,6 +731,9 @@ sub validate () {
             unless (defined($value) && length($value)) {
                 $thisfail = ++$bad;
             }
+        } elsif (! defined $pattern) {
+            debug 2, "$field: length('$value') > 0";
+            $thisfail = ++$bad unless length($value) > 0;
         } else {
             # literal string is a literal comparison, but warn of typos...
             belch "Validation string '$pattern' may be a typo of a builtin pattern"
@@ -667,6 +749,22 @@ sub validate () {
         # Just for debugging's sake
         $thisfail ? debug 2, "$field: pattern FAILED"
                   : debug 2, "$field: pattern passed";
+        
+        # run inflation subref if defined, trap errors and warn
+        if (defined $inflate) {
+            debug 1, "trying to inflate value '$value'";
+            my $inflated_value = eval { $inflate->($value) };
+            if ($@) {
+                belch "Field $field: inflate failed on value '$value' due to '$@'";
+                $thisfail = ++$bad;
+            }
+            # cache for value():
+            push @{$self->{inflated_values}}, $inflated_value;
+
+            # debugging:
+            $thisfail ? debug 2, "$field: inflate FAILED"
+                      : debug 2, "$field: inflate passed";
+        }
     }
 
     # If not $atleastone and they asked for validation, then we
@@ -674,20 +772,16 @@ sub validate () {
     if ($bad || (! $atleastone && $self->required)) {
         debug 1, "$field: validation FAILED";
         $self->{invalid} = $bad || 1;
+        $self->{missing} = $atleastone;  
         return;
     } else {
         debug 1, "$field: validation passed";
         delete $self->{invalid};    # in case of previous run
+        delete $self->{missing};    # ditto
         return 1;
     }
 }
 
-sub invalid () {
-    my $self = shift;
-    # return stored value, assume validate run first
-    @_ ? $self->{invalid} = shift : $self->{invalid};
-}
-
 sub static () {
     my $self = shift;
     $self->{static} = shift if @_;
@@ -803,6 +897,25 @@ Once you have a C<$field> object, you call this method the exact same way
 that you would call the main C<field()> method, minus the field name. Again
 you should use the top-level call instead.
 
+=head2 inflate($subref)
+
+This sets the inflate attribute: subroutine reference used to inflate values 
+returned by value() into objects or whatever you want.  If no parameter, 
+returns the inflate subroutine reference that is set.  For example:
+    
+ use DateTime::Format::Strptime;
+ my $date_format = DateTime::Format::Strptime->new(
+    pattern   => '%D',    # for MM/DD/YYYY american dates
+    locale    => 'en_US',
+    time_zone => 'America/Los_Angeles',
+ );
+ $field->inflate( sub { return $date_format->format_datetime(shift) } );
+
+=head2 invalid
+
+This returns the opposite value that C<validate()> would return, with
+some extra magic that keeps state for form rendering purposes.
+
 =head2 jsfunc()
 
 Returns the appropriate JavaScript validation code (see above).
@@ -853,11 +966,6 @@ call in FormBuilder. Usually running per-field validate() calls is not
 what you want. Instead, you want to run the one on C<$form>, which in
 turn calls each individual field's and saves some temp state.
 
-=head2 invalid
-
-This returns the opposite value that C<validate()> would return, with
-some extra magic that keeps state for form rendering purposes.
-
 =head2 value($val)
 
 This sets the field's value. It also returns the appropriate value: CGI if
@@ -878,6 +986,13 @@ This always returns the CGI value, regardless of C<sticky>.
 
 This always returns the default value, regardless of C<sticky>.
 
+=head2 tag_name()
+
+This returns the tag name of the current item. This was added so you could
+subclass, say, C<CGI::FormBuilder::Field::select> and change the HTML tag
+to C<< <b:select> >> instead. This is an experimental feature and subject
+to change wildly (suggestions welcome).
+
 =head2 accessors
 
 In addition to the above methods, accessors are provided for directly 
@@ -902,11 +1017,11 @@ L<CGI::FormBuilder>
 
 =head1 REVISION
 
-$Id: Field.pm,v 1.71 2006/02/24 01:42:29 nwiger Exp $
+$Id: Field.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
