@@ -1,28 +1,21 @@
 ﻿
-# Copyright (c) 2005 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Use "perldoc CGI::FormBuilder::Messages" to read full documentation.
+###########################################################################
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
+###########################################################################
 
 package CGI::FormBuilder::Messages::locale;
 
-=head1 NAME
-
-CGI::FormBuilder::Messages::fr_FR - French messages for FormBuilder
-
-=head1 SYNOPSIS
-
-    use CGI::FormBuilder;
-
-    my $form = CGI::FormBuilder->new(messages => 'fr');
-
-=cut
-
 use strict;
 use utf8;
 
-our $VERSION = '3.03';
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-# Simply create a hash of messages for this language
-our %MESSAGES = (
+our $VERSION = '3.10';
+
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'fr_FR',
     charset               => 'utf-8',
 
@@ -74,45 +67,8 @@ Pour toute question, veuillez contacter nos services
 en répondant à cet email.'
 EOT
     mail_results_subject  => 'Résultats du formulaire %s',
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
 
-=head1 DESCRIPTION
-
-This module contains French messages for FormBuilder.
-
-If the C<messages> option is set to "auto" (the recommended
-but NOT default setting), these messages will automatically
-be displayed to French clients: 
-
-     my $form = CGI::FormBuilder->new(messages => 'auto');
-
-To force display of these messages, use the following
-option:
-
-     my $form = CGI::FormBuilder->new(messages => ':fr_FR');
-
-Thanks to Laurent Dami for the French translation.
-
-=head1 REVISION
-
-$Id: fr_FR.pm,v 1.8 2006/02/24 01:42:29 nwiger Exp $
-
-=head1 AUTHOR
-
-Copyright (c) 2005-2006 Nate Wiger <nate@wiger.org>,
-Laurent Dami <dami@cpan.org>. All Rights Reserved.
-
-This module is free software; you may copy this under the terms of
-the GNU General Public License, or the Artistic License, copies of
-which should have accompanied your Perl kit.
-
-=cut
-
