@@ -1,6 +1,8 @@
 
-# Copyright (c) 2005 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Use "perldoc CGI::FormBuilder::Source" to read full documentation.
+###########################################################################
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
+###########################################################################
 
 package CGI::FormBuilder::Source;
 
@@ -40,8 +42,10 @@ CGI::FormBuilder::Source - Source adapters for FormBuilder
 =cut
 
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
-our $VERSION = '3.0302';
+our $VERSION = '3.10';
 warn __PACKAGE__, " is not a real module, please read the docs\n"; 
 1;
 __END__
@@ -98,11 +102,11 @@ L<CGI::FormBuilder>, L<CGI::FormBuilder::Source::File>,
 
 =head1 REVISION
 
-$Id: Source.pm,v 1.16 2006/02/24 01:42:29 nwiger Exp $
+$Id: Source.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
