@@ -1,6 +1,8 @@
 
-# Copyright (c) 2005 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Use "perldoc CGI::FormBuilder::Template" to read full documentation.
+###########################################################################
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
+###########################################################################
 
 package CGI::FormBuilder::Template;
 
@@ -46,8 +48,10 @@ CGI::FormBuilder::Template - Template adapters for FormBuilder
 =cut
 
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
-our $VERSION = '3.0302';
+our $VERSION = '3.10';
 warn __PACKAGE__, " is not a real module, please read the docs\n"; 
 1;
 __END__
@@ -97,13 +101,16 @@ would look like this:
 The C<type> option specifies the name of the engine. Currently accepted
 types are:
 
-    HTML  -  HTML::Template (default)
-    Text  -  Text::Template
-    TT2   -  Template Toolkit
-    Fast  -  CGI::FastTemplate
+    Builtin -  Included, default rendering if no template specified
+    Div     -  Render form using <div> (no tables)
+    HTML    -  HTML::Template
+    Text    -  Text::Template
+    TT2     -  Template Toolkit
+    Fast    -  CGI::FastTemplate
+    CGI_SSI -  CGI::SSI
 
 In addition to one of these types, you can also specify a complete package name,
-in which case that module will be autoloaded and its C<new()> and C<parse()>
+in which case that module will be autoloaded and its C<new()> and C<render()>
 routines used. For example:
 
     my $form = CGI::FormBuilder->new(
@@ -185,15 +192,15 @@ the guts of one of the existing template engines and go from there.
 
 L<CGI::FormBuilder>, L<CGI::FormBuilder::Template::HTML>,
 L<CGI::FormBuilder::Template::Text>, L<CGI::FormBuilder::Template::TT2>,
-L<CGI::FormBuilder::Template::Fast>
+L<CGI::FormBuilder::Template::Fast>, L<CGI::FormBuilder::Template::CGI_SSI>
 
 =head1 REVISION
 
-$Id: Template.pm,v 1.30 2006/02/24 01:42:29 nwiger Exp $
+$Id: Template.pm 97 2007-02-06 17:10:39Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
