@@ -1,6 +1,8 @@
 
-# Copyright (c) 2005 Nate Wiger <nate@wiger.org>. All Rights Reserved.
-# Use "perldoc CGI::FormBuilder::Test" to read full documentation.
+###########################################################################
+# Copyright (c) Nate Wiger http://nateware.com. All Rights Reserved.
+# Please visit http://formbuilder.org for tutorials, support, and examples.
+###########################################################################
 
 package CGI::FormBuilder::Test;
 
@@ -21,15 +23,20 @@ CGI::FormBuilder::Test - Test harness for FormBuilder
 =cut
 
 use strict;
+use warnings;
+no  warnings 'uninitialized';
 
-our $VERSION = '3.0302';
+use CGI::FormBuilder::Util;
+
+
+our $VERSION = '3.10';
 our $DEBUG = 0;
 
 use Exporter;
 use base 'Exporter';
 our @EXPORT = qw(outfile);
 
-use File::Basename;
+use File::Basename 'fileparse';
 use File::Spec::Functions;
 
 sub outfile ($) {
@@ -44,13 +51,13 @@ sub outfile ($) {
 
 =head1 DESCRIPTION
 
-=head1 VERSION
+=head1 REVISION
 
-$Id: Test.pm,v 1.14 2006/02/24 01:42:29 nwiger Exp $
+$Id: Test.pm 100 2007-03-02 18:13:13Z nwiger $
 
 =head1 AUTHOR
 
-Copyright (c) 2005-2006 Nate Wiger <nate@wiger.org>. All Rights Reserved.
+Copyright (c) L<Nate Wiger|http://nateware.com>. All Rights Reserved.
 
 This module is free software; you may copy this under the terms of
 the GNU General Public License, or the Artistic License, copies of
